@@ -5,7 +5,7 @@ class __Anchor(_pre.Pregex):
     Every "Anchor" class must inherit from this class.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex, transform):
+    def __init__(self, pre: _pre.Pregex or str, transform):
         pre = __class__._to_pregex(pre)
         super().__init__(transform(pre), group_on_concat=False)
 
@@ -15,7 +15,7 @@ class __Lookaround(_pre.Pregex):
     Every "Lookaround" class must inherit from this class.
     '''
 
-    def __init__(self, pre1: str or _pre.Pregex, pre2: str or _pre.Pregex, transform):
+    def __init__(self, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str, transform):
         pre1, pre2 = __class__._to_pregex(pre1), __class__._to_pregex(pre2)
         super().__init__(transform(pre1, pre2), group_on_concat=False, group_on_quantify=True)
 
@@ -24,10 +24,12 @@ class MatchAtStart(__Anchor):
     '''
     Matches the provided pattern only if said pattern is at the start of the string.
 
+    :param Pregex | str pre: The pattern that is to be matched.
+
     NOTE: Cannot be quantified.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern is at the start of the string.
 
@@ -42,10 +44,12 @@ class MatchAtEnd(__Anchor):
     '''
     Matches the provided pattern only if said pattern is at the end of the string.
 
+    :param Pregex | str pre: The pattern that is to be matched.
+
     NOTE: Cannot be quantified.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern is at the end of the string.
 
@@ -60,12 +64,14 @@ class MatchAtLineStart(__Anchor):
     '''
     Matches the provided pattern only if said pattern is at the start of a line.
 
+    :param Pregex | str pre: The pattern that is to be matched.
+
     NOTE: 
         - Cannot be quantified.
         - Uses meta character "^" since the "MULTILINE" flag is considered on.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern is at the end of the string.
 
@@ -82,12 +88,14 @@ class MatchAtLineEnd(__Anchor):
     '''
     Matches the provided pattern only if said pattern is at the end of a line.
 
+    :param Pregex | str pre: The pattern that is to be matched.
+
     NOTE: 
         - Cannot be quantified.
         - Uses meta character "$" since the "MULTILINE" flag is considered on.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern is at the end of a line.
 
@@ -104,9 +112,11 @@ class MatchAtWordBoundary(__Anchor):
     '''
     Matches the provided pattern only if said pattern has \
     a word boundary on both its sides.
+
+    :param Pregex | str pre: The pattern that is to be matched.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern has \
         a word boundary on both its sides.
@@ -119,9 +129,11 @@ class MatchAtLeftWordBoundary(__Anchor):
     '''
     Matches the provided pattern only when said pattern has \
     a word boundary on its left side.
+
+    :param Pregex | str pre: The pattern that is to be matched.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern has \
         a word boundary on its left side.
@@ -135,9 +147,11 @@ class MatchAtRightWordBoundary(__Anchor):
     '''
     Matches the provided pattern only when said pattern has \
     a word boundary on its right side.
+
+    :param Pregex | str pre: The pattern that is to be matched.
     '''
 
-    def __init__(self, pre: str or _pre.Pregex):
+    def __init__(self, pre: _pre.Pregex or str):
         '''
         Matches the provided pattern only if said pattern has \
         a word boundary on its right side.
@@ -151,9 +165,12 @@ class FollowedBy(__Lookaround):
     '''
     Matches pattern 'pre1' only if it is followed by pattern 'pre2', \
     without the latter being included into the match.
+
+    :param Pregex | str pre1: The pattern that is to be matched.
+    :param Pregex | str pre2: The pattern that must follow pattern 'pre1'.
     '''
 
-    def __init__(self, pre1: str or _pre.Pregex, pre2: str or _pre.Pregex):
+    def __init__(self, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str):
         '''
         Matches pattern 'pre1' only if it is followed by pattern 'pre2', \
         without the latter being included into the match.
@@ -168,9 +185,12 @@ class NotFollowedBy(__Lookaround):
     '''
     Matches pattern 'pre1' only if it is not followed by pattern 'pre2', \
     without the latter being included into the match.
+
+    :param Pregex | str pre1: The pattern that is to be matched.
+    :param Pregex | str pre2: The pattern that must not follow pattern 'pre1'.
     '''
 
-    def __init__(self, pre1: str or _pre.Pregex, pre2: str or _pre.Pregex):
+    def __init__(self, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str):
         '''
         Matches pattern 'pre1' only if it is not followed by pattern 'pre2', \
         without the latter being included into the match.
@@ -185,9 +205,12 @@ class PrecededBy(__Lookaround):
     '''
     Matches pattern 'pre1' only if it is preceded by pattern 'pre2', \
     without the latter being included into the match.
+
+    :param Pregex | str pre1: The pattern that is to be matched.
+    :param Pregex | str pre2: The pattern that must precede pattern 'pre1'.
     '''
 
-    def __init__(self, pre1: str or _pre.Pregex, pre2: str or _pre.Pregex):
+    def __init__(self, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str):
         '''
         Matches pattern 'pre1' only if it is preceded by pattern 'pre2', \
         without the latter being included into the match.
@@ -202,9 +225,12 @@ class NotPrecededBy(__Lookaround):
     '''
     Matches pattern 'pre1' only if it is not preceded by pattern 'pre2', \
     without the latter being included into the match.
+
+    :param Pregex | str pre1: The pattern that is to be matched.
+    :param Pregex | str pre2: The pattern that must not precede pattern 'pre1'.
     '''
 
-    def __init__(self, pre1: str or _pre.Pregex, pre2: str or _pre.Pregex):
+    def __init__(self, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str):
         '''
         Matches pattern 'pre1' only if it is not preceded by pattern 'pre2', \
         without the latter being included into the match.
